/* ============================================================ */
/*   Nom de la base   :  MCD_HOTEL                              */
/*   Nom de SGBD      :  INGRES Version 6.4                     */
/*   Date de cration :  16/01/2001  22:33                      */
/*   Copyright        :  Frdric BROUARD                       */
/* ============================================================ */

set autocommit on\g
set lockmode session where readlock=nolock, level=table\g

/* ============================================================ */
/*   Table : T_CHAMBRE                                          */
/* ============================================================ */
create table T_CHAMBRE
(
    CHB_ID               INTEGER               not null ,
    CHB_NUMERO           SMALLINT              not null ,
    CHB_ETAGE            CHAR(3)                        ,
    CHB_BAIN             INTEGER1              not null ,
    CHB_DOUCHE           INTEGER1              not null ,
    CHB_WC               INTEGER1              not null ,
    CHB_COUCHAGE         SMALLINT              not null ,
    CHB_POSTE_TEL        CHAR(3)                        
)
\g

modify T_CHAMBRE to btree unique on CHB_ID
\g

/* ============================================================ */
/*   Index : T_CHAMBRE_PK                                       */
/* ============================================================ */
create unique index T_CHAMBRE_PK on T_CHAMBRE (CHB_ID asc)
\g

/* ============================================================ */
/*   Table : T_TARIF                                            */
/* ============================================================ */
create table T_TARIF
(
    TRF_DATE_DEBUT       DATE                  not null ,
    TRF_TAUX_TAXES       INTEGER               not null ,
    TRF_PETIT_DEJEUNE    MONEY                 not null 
)
\g

modify T_TARIF to btree unique on TRF_DATE_DEBUT
\g

/* ============================================================ */
/*   Index : T_TARIF_PK                                         */
/* ============================================================ */
create unique index T_TARIF_PK on T_TARIF (TRF_DATE_DEBUT asc)
\g

/* ============================================================ */
/*   Table : T_PLANNING                                         */
/* ============================================================ */
create table T_PLANNING
(
    PLN_JOUR             DATE                  not null 
)
\g

modify T_PLANNING to btree unique on PLN_JOUR
\g

/* ============================================================ */
/*   Index : T_PLANNING_PK                                      */
/* ============================================================ */
create unique index T_PLANNING_PK on T_PLANNING (PLN_JOUR asc)
\g

/* ============================================================ */
/*   Table : T_TITRE                                            */
/* ============================================================ */
create table T_TITRE
(
    TIT_CODE             CHAR(8)               not null ,
    TIT_LIBELLE          VARCHAR(32)           not null 
)
\g

modify T_TITRE to btree unique on TIT_CODE
\g

/* ============================================================ */
/*   Index : T_TITRE_PK                                         */
/* ============================================================ */
create unique index T_TITRE_PK on T_TITRE (TIT_CODE asc)
\g

/* ============================================================ */
/*   Table : T_TYPE                                             */
/* ============================================================ */
create table T_TYPE
(
    TYP_CODE             CHAR(8)               not null ,
    TYP_LIBELLE          VARCHAR(32)           not null 
)
\g

modify T_TYPE to btree unique on TYP_CODE
\g

/* ============================================================ */
/*   Index : T_TYPE_PK                                          */
/* ============================================================ */
create unique index T_TYPE_PK on T_TYPE (TYP_CODE asc)
\g

/* ============================================================ */
/*   Table : T_MODE_PAIEMENT                                    */
/* ============================================================ */
create table T_MODE_PAIEMENT
(
    PMT_CODE             CHAR(8)               not null ,
    PMT_LIBELLE          VARCHAR(64)           not null 
)
\g

modify T_MODE_PAIEMENT to btree unique on PMT_CODE
\g

/* ============================================================ */
/*   Index : T_MODE_PAIEMENT_PK                                 */
/* ============================================================ */
create unique index T_MODE_PAIEMENT_PK on T_MODE_PAIEMENT (PMT_CODE asc)
\g

/* ============================================================ */
/*   Table : T_CLIENT                                           */
/* ============================================================ */
create table T_CLIENT
(
    CLI_ID               INTEGER               not null ,
    TIT_CODE             CHAR(8)                        ,
    CLI_NOM              CHAR(32)              not null ,
    CLI_PRENOM           VARCHAR(25)                    ,
    CLI_ENSEIGNE         VARCHAR(100)                   
)
\g

modify T_CLIENT to btree unique on CLI_ID
\g

/* ============================================================ */
/*   Index : T_CLIENT_PK                                        */
/* ============================================================ */
create unique index T_CLIENT_PK on T_CLIENT (CLI_ID asc)
\g

/* ============================================================ */
/*   Index : L_CLI_TIT_FK                                       */
/* ============================================================ */
create index L_CLI_TIT_FK on T_CLIENT (TIT_CODE asc)
\g

/* ============================================================ */
/*   Table : T_FACTURE                                          */
/* ============================================================ */
create table T_FACTURE
(
    FAC_ID               INTEGER               not null ,
    CLI_ID               INTEGER               not null ,
    PMT_CODE             CHAR(8)                        ,
    FAC_DATE             DATE                  not null ,
    FAC_PMT_DATE         DATE                           
)
\g

modify T_FACTURE to btree unique on FAC_ID
\g

/* ============================================================ */
/*   Index : T_FACTURE_PK                                       */
/* ============================================================ */
create unique index T_FACTURE_PK on T_FACTURE (FAC_ID asc)
\g

/* ============================================================ */
/*   Index : L_FAC_CLI_FK                                       */
/* ============================================================ */
create index L_FAC_CLI_FK on T_FACTURE (CLI_ID asc)
\g

/* ============================================================ */
/*   Index : TJ_FAC_PMT_FK                                      */
/* ============================================================ */
create index TJ_FAC_PMT_FK on T_FACTURE (PMT_CODE asc)
\g

/* ============================================================ */
/*   Table : T_ADRESSE                                          */
/* ============================================================ */
create table T_ADRESSE
(
    ADR_ID               INTEGER               not null ,
    CLI_ID               INTEGER               not null ,
    ADR_LIGNE1           VARCHAR(32)           not null ,
    ADR_LIGNE2           VARCHAR(32)                    ,
    ADR_LIGNE3           VARCHAR(32)                    ,
    ADR_LIGNE4           VARCHAR(32)                    ,
    ADR_CP               CHAR(5)               not null ,
    ADR_VILLE            CHAR(32)              not null 
)
\g

modify T_ADRESSE to btree unique on ADR_ID
\g

/* ============================================================ */
/*   Index : T_ADRESSE_PK                                       */
/* ============================================================ */
create unique index T_ADRESSE_PK on T_ADRESSE (ADR_ID asc)
\g

/* ============================================================ */
/*   Index : L_ADR_CLI_FK                                       */
/* ============================================================ */
create index L_ADR_CLI_FK on T_ADRESSE (CLI_ID asc)
\g

/* ============================================================ */
/*   Table : T_TELEPHONE                                        */
/* ============================================================ */
create table T_TELEPHONE
(
    TEL_ID               INTEGER               not null ,
    CLI_ID               INTEGER               not null ,
    TYP_CODE             CHAR(8)               not null ,
    TEL_NUMERO           CHAR(20)              not null ,
    TEL_LOCALISATION     VARCHAR(64)                    
)
\g

modify T_TELEPHONE to btree unique on TEL_ID
\g

/* ============================================================ */
/*   Index : T_TELEPHONE_PK                                     */
/* ============================================================ */
create unique index T_TELEPHONE_PK on T_TELEPHONE (TEL_ID asc)
\g

/* ============================================================ */
/*   Index : L_TEL_CLI_FK                                       */
/* ============================================================ */
create index L_TEL_CLI_FK on T_TELEPHONE (CLI_ID asc)
\g

/* ============================================================ */
/*   Index : L_TEL_TYP_FK                                       */
/* ============================================================ */
create index L_TEL_TYP_FK on T_TELEPHONE (TYP_CODE asc)
\g

/* ============================================================ */
/*   Table : T_EMAIL                                            */
/* ============================================================ */
create table T_EMAIL
(
    EML_ID               INTEGER               not null ,
    CLI_ID               INTEGER               not null ,
    EML_ADRESSE          VARCHAR(100)          not null ,
    EML_LOCALISATION     VARCHAR(64)                    
)
\g

modify T_EMAIL to btree unique on EML_ID
\g

/* ============================================================ */
/*   Index : T_EMAIL_PK                                         */
/* ============================================================ */
create unique index T_EMAIL_PK on T_EMAIL (EML_ID asc)
\g

/* ============================================================ */
/*   Index : L_EML_CLI_FK                                       */
/* ============================================================ */
create index L_EML_CLI_FK on T_EMAIL (CLI_ID asc)
\g

/* ============================================================ */
/*   Table : T_LIGNE_FACTURE                                    */
/* ============================================================ */
create table T_LIGNE_FACTURE
(
    LIF_ID               INTEGER               not null ,
    FAC_ID               INTEGER               not null ,
    LIF_QTE              INTEGER               not null ,
    LIF_REMISE_POURCENT  INTEGER                        ,
    LIF_REMISE_MONTANT   MONEY                          ,
    LIF_MONTANT          MONEY                 not null ,
    LIF_TAUX_TVA         INTEGER               not null  
)
\g

modify T_LIGNE_FACTURE to btree unique on LIF_ID
\g

/* ============================================================ */
/*   Index : T_LIGNE_FACTURE_PK                                 */
/* ============================================================ */
create unique index T_LIGNE_FACTURE_PK on T_LIGNE_FACTURE (LIF_ID asc)
\g

/* ============================================================ */
/*   Index : L_LIF_FAC_FK                                       */
/* ============================================================ */
create index L_LIF_FAC_FK on T_LIGNE_FACTURE (FAC_ID asc)
\g

/* ============================================================ */
/*   Table : TJ_TRF_CHB                                         */
/* ============================================================ */
create table TJ_TRF_CHB
(
    CHB_ID               INTEGER               not null ,
    TRF_DATE_DEBUT       DATE                  not null ,
    TRF_CHB_PRIX         MONEY                 not null 
)
\g

modify TJ_TRF_CHB to btree unique on CHB_ID, TRF_DATE_DEBUT
\g

/* ============================================================ */
/*   Index : TJ_TRF_CHB_PK                                      */
/* ============================================================ */
create unique index TJ_TRF_CHB_PK on TJ_TRF_CHB (CHB_ID asc, TRF_DATE_DEBUT asc)
\g

/* ============================================================ */
/*   Index : L_CHB_TRF_FK                                       */
/* ============================================================ */
create index L_CHB_TRF_FK on TJ_TRF_CHB (CHB_ID asc)
\g

/* ============================================================ */
/*   Index : L_TRF_CHB_FK                                       */
/* ============================================================ */
create index L_TRF_CHB_FK on TJ_TRF_CHB (TRF_DATE_DEBUT asc)
\g

/* ============================================================ */
/*   Table : TJ_CHB_PLN_CLI                                     */
/* ============================================================ */
create table TJ_CHB_PLN_CLI
(
    CHB_ID               INTEGER               not null ,
    PLN_JOUR             DATE                  not null ,
    CLI_ID               INTEGER               not null ,
    CHB_PLN_CLI_NB_PERS  SMALLINT              not null ,
    CHB_PLN_CLI_RESERVE  INTEGER1              not null ,
    CHB_PLN_CLI_OCCUPE   INTEGER1              not null 
)
\g

modify TJ_CHB_PLN_CLI to btree unique on CHB_ID, PLN_JOUR
\g

/* ============================================================ */
/*   Index : TJ_CHB_PLN_CLI_PK                                  */
/* ============================================================ */
create unique index TJ_CHB_PLN_CLI_PK on TJ_CHB_PLN_CLI (CHB_ID asc, PLN_JOUR asc)
\g

/* ============================================================ */
/*   Index : L_CHB_PLN_CLI_FK                                   */
/* ============================================================ */
create index L_CHB_PLN_CLI_FK on TJ_CHB_PLN_CLI (CHB_ID asc)
\g

/* ============================================================ */
/*   Index : L_PLN_CHB_CLI_FK                                   */
/* ============================================================ */
create index L_PLN_CHB_CLI_FK on TJ_CHB_PLN_CLI (PLN_JOUR asc)
\g

/* ============================================================ */
/*   Index : L_CLI_CHB_PLN_FK                                   */
/* ============================================================ */
create index L_CLI_CHB_PLN_FK on TJ_CHB_PLN_CLI (CLI_ID asc)
\g


\q
